@@ -386,7 +386,7 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn add_student(
         &self,
-        param_student: models::Student,
+        param_student_upsert: models::StudentUpsert,
         context: &C) -> Result<AddStudentResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
@@ -419,7 +419,7 @@ impl<S, C> Api<C> for Client<S, C> where
         };
 
         // Body parameter
-        let body = serde_json::to_string(&param_student).expect("impossible to fail to serialize");
+        let body = serde_json::to_string(&param_student_upsert).expect("impossible to fail to serialize");
                 *request.body_mut() = Body::from(body);
 
         let header = "application/json";
@@ -461,7 +461,7 @@ impl<S, C> Api<C> for Client<S, C> where
                         .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
                 let body = str::from_utf8(&body)
                     .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
-                let body = serde_json::from_str::<models::Student>(body)?;
+                let body = serde_json::from_str::<models::StudentUpsert>(body)?;
                 Ok(AddStudentResponse::SuccessfulOperation
                     (body)
                 )
@@ -595,7 +595,7 @@ impl<S, C> Api<C> for Client<S, C> where
     async fn update_student(
         &self,
         param_id: uuid::Uuid,
-        param_student: models::Student,
+        param_student_upsert: models::StudentUpsert,
         context: &C) -> Result<UpdateStudentResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
@@ -628,7 +628,7 @@ impl<S, C> Api<C> for Client<S, C> where
                 Err(e) => return Err(ApiError(format!("Unable to create request: {}", e)))
         };
 
-        let body = serde_json::to_string(&param_student).expect("impossible to fail to serialize");
+        let body = serde_json::to_string(&param_student_upsert).expect("impossible to fail to serialize");
 
                 *request.body_mut() = Body::from(body);
 
@@ -672,7 +672,7 @@ impl<S, C> Api<C> for Client<S, C> where
                         .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
                 let body = str::from_utf8(&body)
                     .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
-                let body = serde_json::from_str::<models::Student>(body)?;
+                let body = serde_json::from_str::<models::StudentUpsert>(body)?;
                 Ok(UpdateStudentResponse::SuccessfulOperation
                     (body)
                 )
@@ -784,7 +784,7 @@ impl<S, C> Api<C> for Client<S, C> where
                         .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
                 let body = str::from_utf8(&body)
                     .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
-                let body = serde_json::from_str::<models::Student>(body)?;
+                let body = serde_json::from_str::<models::StudentUpsert>(body)?;
                 Ok(GetStudentByIdResponse::SuccessfulOperation
                     (body)
                 )
