@@ -4,263 +4,6 @@ use crate::models;
 #[cfg(any(feature = "client", feature = "server"))]
 use crate::header;
 
-/// Student info
-#[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
-#[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
-#[serde(rename = "student")]
-pub struct Student {
-    #[serde(rename = "id")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub id: Option<uuid::Uuid>,
-
-    #[serde(rename = "polityId")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub polity_id: Option<uuid::Uuid>,
-
-    #[serde(rename = "saintIdArray")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub saint_id_array: Option<Vec<uuid::Uuid>>,
-
-    // Note: inline enums are not fully supported by openapi-generator
-    #[serde(rename = "title")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub title: Option<String>,
-
-    #[serde(rename = "firstName")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub first_name: Option<String>,
-
-    #[serde(rename = "middleName")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub middle_name: Option<String>,
-
-    #[serde(rename = "lastName")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub last_name: Option<String>,
-
-    /// date of birth in format YYYY-MM-DD
-    #[serde(rename = "dateOfBirth")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
-
-    #[serde(rename = "placeOfBirth")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub place_of_birth: Option<String>,
-
-    #[serde(rename = "email")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub email: Option<String>,
-
-    #[serde(rename = "phone")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub phone: Option<String>,
-
-    #[serde(rename = "undergraduateSchool")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub undergraduate_school: Option<String>,
-
-}
-
-impl Student {
-    pub fn new() -> Student {
-        Student {
-            id: None,
-            polity_id: None,
-            saint_id_array: None,
-            title: None,
-            first_name: None,
-            middle_name: None,
-            last_name: None,
-            date_of_birth: None,
-            place_of_birth: None,
-            email: None,
-            phone: None,
-            undergraduate_school: None,
-        }
-    }
-}
-
-/// Converts the Student value to the Query Parameters representation (style=form, explode=false)
-/// specified in https://swagger.io/docs/specification/serialization/
-/// Should be implemented in a serde serializer
-impl std::string::ToString for Student {
-    fn to_string(&self) -> String {
-        let mut params: Vec<String> = vec![];
-        // Skipping id in query parameter serialization
-
-        // Skipping polityId in query parameter serialization
-
-        // Skipping saintIdArray in query parameter serialization
-
-
-        if let Some(ref title) = self.title {
-            params.push("title".to_string());
-            params.push(title.to_string());
-        }
-
-
-        if let Some(ref first_name) = self.first_name {
-            params.push("firstName".to_string());
-            params.push(first_name.to_string());
-        }
-
-
-        if let Some(ref middle_name) = self.middle_name {
-            params.push("middleName".to_string());
-            params.push(middle_name.to_string());
-        }
-
-
-        if let Some(ref last_name) = self.last_name {
-            params.push("lastName".to_string());
-            params.push(last_name.to_string());
-        }
-
-        // Skipping dateOfBirth in query parameter serialization
-
-
-        if let Some(ref place_of_birth) = self.place_of_birth {
-            params.push("placeOfBirth".to_string());
-            params.push(place_of_birth.to_string());
-        }
-
-
-        if let Some(ref email) = self.email {
-            params.push("email".to_string());
-            params.push(email.to_string());
-        }
-
-
-        if let Some(ref phone) = self.phone {
-            params.push("phone".to_string());
-            params.push(phone.to_string());
-        }
-
-
-        if let Some(ref undergraduate_school) = self.undergraduate_school {
-            params.push("undergraduateSchool".to_string());
-            params.push(undergraduate_school.to_string());
-        }
-
-        params.join(",").to_string()
-    }
-}
-
-/// Converts Query Parameters representation (style=form, explode=false) to a Student value
-/// as specified in https://swagger.io/docs/specification/serialization/
-/// Should be implemented in a serde deserializer
-impl std::str::FromStr for Student {
-    type Err = String;
-
-    fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
-        #[derive(Default)]
-        // An intermediate representation of the struct to use for parsing.
-        struct IntermediateRep {
-            pub id: Vec<uuid::Uuid>,
-            pub polity_id: Vec<uuid::Uuid>,
-            pub saint_id_array: Vec<Vec<uuid::Uuid>>,
-            pub title: Vec<String>,
-            pub first_name: Vec<String>,
-            pub middle_name: Vec<String>,
-            pub last_name: Vec<String>,
-            pub date_of_birth: Vec<chrono::DateTime::<chrono::Utc>>,
-            pub place_of_birth: Vec<String>,
-            pub email: Vec<String>,
-            pub phone: Vec<String>,
-            pub undergraduate_school: Vec<String>,
-        }
-
-        let mut intermediate_rep = IntermediateRep::default();
-
-        // Parse into intermediate representation
-        let mut string_iter = s.split(',').into_iter();
-        let mut key_result = string_iter.next();
-
-        while key_result.is_some() {
-            let val = match string_iter.next() {
-                Some(x) => x,
-                None => return std::result::Result::Err("Missing value while parsing Student".to_string())
-            };
-
-            if let Some(key) = key_result {
-                match key {
-                    "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "polityId" => intermediate_rep.polity_id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "saintIdArray" => return std::result::Result::Err("Parsing a container in this style is not supported in Student".to_string()),
-                    "title" => intermediate_rep.title.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "firstName" => intermediate_rep.first_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "middleName" => intermediate_rep.middle_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "lastName" => intermediate_rep.last_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "dateOfBirth" => intermediate_rep.date_of_birth.push(<chrono::DateTime::<chrono::Utc> as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "placeOfBirth" => intermediate_rep.place_of_birth.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "email" => intermediate_rep.email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "phone" => intermediate_rep.phone.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "undergraduateSchool" => intermediate_rep.undergraduate_school.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    _ => return std::result::Result::Err("Unexpected key while parsing Student".to_string())
-                }
-            }
-
-            // Get the next key
-            key_result = string_iter.next();
-        }
-
-        // Use the intermediate representation to return the struct
-        std::result::Result::Ok(Student {
-            id: intermediate_rep.id.into_iter().next(),
-            polity_id: intermediate_rep.polity_id.into_iter().next(),
-            saint_id_array: intermediate_rep.saint_id_array.into_iter().next(),
-            title: intermediate_rep.title.into_iter().next(),
-            first_name: intermediate_rep.first_name.into_iter().next(),
-            middle_name: intermediate_rep.middle_name.into_iter().next(),
-            last_name: intermediate_rep.last_name.into_iter().next(),
-            date_of_birth: intermediate_rep.date_of_birth.into_iter().next(),
-            place_of_birth: intermediate_rep.place_of_birth.into_iter().next(),
-            email: intermediate_rep.email.into_iter().next(),
-            phone: intermediate_rep.phone.into_iter().next(),
-            undergraduate_school: intermediate_rep.undergraduate_school.into_iter().next(),
-        })
-    }
-}
-
-// Methods for converting between header::IntoHeaderValue<Student> and hyper::header::HeaderValue
-
-#[cfg(any(feature = "client", feature = "server"))]
-impl std::convert::TryFrom<header::IntoHeaderValue<Student>> for hyper::header::HeaderValue {
-    type Error = String;
-
-    fn try_from(hdr_value: header::IntoHeaderValue<Student>) -> std::result::Result<Self, Self::Error> {
-        let hdr_value = hdr_value.to_string();
-        match hyper::header::HeaderValue::from_str(&hdr_value) {
-             std::result::Result::Ok(value) => std::result::Result::Ok(value),
-             std::result::Result::Err(e) => std::result::Result::Err(
-                 format!("Invalid header value for Student - value: {} is invalid {}",
-                     hdr_value, e))
-        }
-    }
-}
-
-#[cfg(any(feature = "client", feature = "server"))]
-impl std::convert::TryFrom<hyper::header::HeaderValue> for header::IntoHeaderValue<Student> {
-    type Error = String;
-
-    fn try_from(hdr_value: hyper::header::HeaderValue) -> std::result::Result<Self, Self::Error> {
-        match hdr_value.to_str() {
-             std::result::Result::Ok(value) => {
-                    match <Student as std::str::FromStr>::from_str(value) {
-                        std::result::Result::Ok(value) => std::result::Result::Ok(header::IntoHeaderValue(value)),
-                        std::result::Result::Err(err) => std::result::Result::Err(
-                            format!("Unable to convert header value '{}' into Student - {}",
-                                value, err))
-                    }
-             },
-             std::result::Result::Err(e) => std::result::Result::Err(
-                 format!("Unable to convert header: {:?} to string: {}",
-                     hdr_value, e))
-        }
-    }
-}
-
-
 /// Enumeration of values.
 /// Since this enum's variants do not hold data, we can easily define them them as `#[repr(C)]`
 /// which helps with FFI.
@@ -328,14 +71,260 @@ impl std::str::FromStr for StudentSortCriteria {
     }
 }
 
+/// Student info
+#[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
+#[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
+#[serde(rename = "student")]
+pub struct StudentUpsert {
+    #[serde(rename = "polityId")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub polity_id: Option<uuid::Uuid>,
+
+    #[serde(rename = "saintIdArray")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub saint_id_array: Option<Vec<uuid::Uuid>>,
+
+    // Note: inline enums are not fully supported by openapi-generator
+    #[serde(rename = "title")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub title: Option<String>,
+
+    #[serde(rename = "firstName")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub first_name: Option<String>,
+
+    #[serde(rename = "middleName")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub middle_name: Option<String>,
+
+    #[serde(rename = "lastName")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub last_name: Option<String>,
+
+    /// date of birth in format YYYY-MM-DD
+    #[serde(rename = "dateOfBirth")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
+
+    #[serde(rename = "placeOfBirth")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub place_of_birth: Option<String>,
+
+    #[serde(rename = "email")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub email: Option<String>,
+
+    #[serde(rename = "phone")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub phone: Option<String>,
+
+    #[serde(rename = "undergraduateSchool")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub undergraduate_school: Option<String>,
+
+}
+
+impl StudentUpsert {
+    pub fn new() -> StudentUpsert {
+        StudentUpsert {
+            polity_id: None,
+            saint_id_array: None,
+            title: None,
+            first_name: None,
+            middle_name: None,
+            last_name: None,
+            date_of_birth: None,
+            place_of_birth: None,
+            email: None,
+            phone: None,
+            undergraduate_school: None,
+        }
+    }
+}
+
+/// Converts the StudentUpsert value to the Query Parameters representation (style=form, explode=false)
+/// specified in https://swagger.io/docs/specification/serialization/
+/// Should be implemented in a serde serializer
+impl std::string::ToString for StudentUpsert {
+    fn to_string(&self) -> String {
+        let mut params: Vec<String> = vec![];
+        // Skipping polityId in query parameter serialization
+
+        // Skipping saintIdArray in query parameter serialization
+
+
+        if let Some(ref title) = self.title {
+            params.push("title".to_string());
+            params.push(title.to_string());
+        }
+
+
+        if let Some(ref first_name) = self.first_name {
+            params.push("firstName".to_string());
+            params.push(first_name.to_string());
+        }
+
+
+        if let Some(ref middle_name) = self.middle_name {
+            params.push("middleName".to_string());
+            params.push(middle_name.to_string());
+        }
+
+
+        if let Some(ref last_name) = self.last_name {
+            params.push("lastName".to_string());
+            params.push(last_name.to_string());
+        }
+
+        // Skipping dateOfBirth in query parameter serialization
+
+
+        if let Some(ref place_of_birth) = self.place_of_birth {
+            params.push("placeOfBirth".to_string());
+            params.push(place_of_birth.to_string());
+        }
+
+
+        if let Some(ref email) = self.email {
+            params.push("email".to_string());
+            params.push(email.to_string());
+        }
+
+
+        if let Some(ref phone) = self.phone {
+            params.push("phone".to_string());
+            params.push(phone.to_string());
+        }
+
+
+        if let Some(ref undergraduate_school) = self.undergraduate_school {
+            params.push("undergraduateSchool".to_string());
+            params.push(undergraduate_school.to_string());
+        }
+
+        params.join(",").to_string()
+    }
+}
+
+/// Converts Query Parameters representation (style=form, explode=false) to a StudentUpsert value
+/// as specified in https://swagger.io/docs/specification/serialization/
+/// Should be implemented in a serde deserializer
+impl std::str::FromStr for StudentUpsert {
+    type Err = String;
+
+    fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
+        #[derive(Default)]
+        // An intermediate representation of the struct to use for parsing.
+        struct IntermediateRep {
+            pub polity_id: Vec<uuid::Uuid>,
+            pub saint_id_array: Vec<Vec<uuid::Uuid>>,
+            pub title: Vec<String>,
+            pub first_name: Vec<String>,
+            pub middle_name: Vec<String>,
+            pub last_name: Vec<String>,
+            pub date_of_birth: Vec<chrono::DateTime::<chrono::Utc>>,
+            pub place_of_birth: Vec<String>,
+            pub email: Vec<String>,
+            pub phone: Vec<String>,
+            pub undergraduate_school: Vec<String>,
+        }
+
+        let mut intermediate_rep = IntermediateRep::default();
+
+        // Parse into intermediate representation
+        let mut string_iter = s.split(',').into_iter();
+        let mut key_result = string_iter.next();
+
+        while key_result.is_some() {
+            let val = match string_iter.next() {
+                Some(x) => x,
+                None => return std::result::Result::Err("Missing value while parsing StudentUpsert".to_string())
+            };
+
+            if let Some(key) = key_result {
+                match key {
+                    "polityId" => intermediate_rep.polity_id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "saintIdArray" => return std::result::Result::Err("Parsing a container in this style is not supported in StudentUpsert".to_string()),
+                    "title" => intermediate_rep.title.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "firstName" => intermediate_rep.first_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "middleName" => intermediate_rep.middle_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "lastName" => intermediate_rep.last_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "dateOfBirth" => intermediate_rep.date_of_birth.push(<chrono::DateTime::<chrono::Utc> as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "placeOfBirth" => intermediate_rep.place_of_birth.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "email" => intermediate_rep.email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "phone" => intermediate_rep.phone.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "undergraduateSchool" => intermediate_rep.undergraduate_school.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    _ => return std::result::Result::Err("Unexpected key while parsing StudentUpsert".to_string())
+                }
+            }
+
+            // Get the next key
+            key_result = string_iter.next();
+        }
+
+        // Use the intermediate representation to return the struct
+        std::result::Result::Ok(StudentUpsert {
+            polity_id: intermediate_rep.polity_id.into_iter().next(),
+            saint_id_array: intermediate_rep.saint_id_array.into_iter().next(),
+            title: intermediate_rep.title.into_iter().next(),
+            first_name: intermediate_rep.first_name.into_iter().next(),
+            middle_name: intermediate_rep.middle_name.into_iter().next(),
+            last_name: intermediate_rep.last_name.into_iter().next(),
+            date_of_birth: intermediate_rep.date_of_birth.into_iter().next(),
+            place_of_birth: intermediate_rep.place_of_birth.into_iter().next(),
+            email: intermediate_rep.email.into_iter().next(),
+            phone: intermediate_rep.phone.into_iter().next(),
+            undergraduate_school: intermediate_rep.undergraduate_school.into_iter().next(),
+        })
+    }
+}
+
+// Methods for converting between header::IntoHeaderValue<StudentUpsert> and hyper::header::HeaderValue
+
+#[cfg(any(feature = "client", feature = "server"))]
+impl std::convert::TryFrom<header::IntoHeaderValue<StudentUpsert>> for hyper::header::HeaderValue {
+    type Error = String;
+
+    fn try_from(hdr_value: header::IntoHeaderValue<StudentUpsert>) -> std::result::Result<Self, Self::Error> {
+        let hdr_value = hdr_value.to_string();
+        match hyper::header::HeaderValue::from_str(&hdr_value) {
+             std::result::Result::Ok(value) => std::result::Result::Ok(value),
+             std::result::Result::Err(e) => std::result::Result::Err(
+                 format!("Invalid header value for StudentUpsert - value: {} is invalid {}",
+                     hdr_value, e))
+        }
+    }
+}
+
+#[cfg(any(feature = "client", feature = "server"))]
+impl std::convert::TryFrom<hyper::header::HeaderValue> for header::IntoHeaderValue<StudentUpsert> {
+    type Error = String;
+
+    fn try_from(hdr_value: hyper::header::HeaderValue) -> std::result::Result<Self, Self::Error> {
+        match hdr_value.to_str() {
+             std::result::Result::Ok(value) => {
+                    match <StudentUpsert as std::str::FromStr>::from_str(value) {
+                        std::result::Result::Ok(value) => std::result::Result::Ok(header::IntoHeaderValue(value)),
+                        std::result::Result::Err(err) => std::result::Result::Err(
+                            format!("Unable to convert header value '{}' into StudentUpsert - {}",
+                                value, err))
+                    }
+             },
+             std::result::Result::Err(e) => std::result::Result::Err(
+                 format!("Unable to convert header: {:?} to string: {}",
+                     hdr_value, e))
+        }
+    }
+}
+
+
 /// Student View
 #[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
 #[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
 #[serde(rename = "student-view")]
 pub struct StudentView {
     #[serde(rename = "id")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub id: Option<uuid::Uuid>,
+    pub id: uuid::Uuid,
 
     #[serde(rename = "polityName")]
     #[serde(skip_serializing_if="Option::is_none")]
@@ -394,9 +383,9 @@ pub struct StudentView {
 }
 
 impl StudentView {
-    pub fn new() -> StudentView {
+    pub fn new(id: uuid::Uuid, ) -> StudentView {
         StudentView {
-            id: None,
+            id: id,
             polity_name: None,
             polity_location_name: None,
             polity_location_address: None,
@@ -564,7 +553,7 @@ impl std::str::FromStr for StudentView {
 
         // Use the intermediate representation to return the struct
         std::result::Result::Ok(StudentView {
-            id: intermediate_rep.id.into_iter().next(),
+            id: intermediate_rep.id.into_iter().next().ok_or("id missing in StudentView".to_string())?,
             polity_name: intermediate_rep.polity_name.into_iter().next(),
             polity_location_name: intermediate_rep.polity_location_name.into_iter().next(),
             polity_location_address: intermediate_rep.polity_location_address.into_iter().next(),
